glymur: a Python interface for JPEG 2000
=========================================

**glymur** contains a Python interface to the OpenJPEG library which
allows one to read and write JPEG 2000 files.  **glymur** works on
Python 2.7, 3.4, 3.5, 3.6, and 3.7.

Please read the docs, https://glymur.readthedocs.org/
